@@ -1,10 +1,8 @@
 package App::Adenosine;
-
+$App::Adenosine::VERSION = '2.001007';
 use strict;
 use warnings;
 
-our $VERSION = '2.001006'; # VERSION
-
 # ABSTRACT: Handy CLI HTTP tool
 
 use URI;
@@ -17,7 +15,7 @@ use Text::ParseWords;
 use Scalar::Util 'blessed';
 use Module::Runtime 'use_module';
 
-our $verb_regex = '(?:HEAD|OPTIONS|GET|DELETE|PUT|POST|TRACE)';
+our $verb_regex = '(?:HEAD|OPTIONS|GET|DELETE|PUT|POST|TRACE|PATCH)';
 
 sub verbose { $_[0]->{verbose} }
 sub plugins { @{$_[0]->{plugins}} }
@@ -88,7 +86,7 @@ sub new {
 
       my @extra = (@ARGV, $self->_get_extra_options);
       my $wantdata;
-      $wantdata = 1 if $action =~ m/^(?:PUT|POST|TRACE)$/;
+      $wantdata = 1 if $action =~ m/^(?:PUT|POST|TRACE|PATCH)$/;
       if ($wantdata && $interactive_edit) {
          require File::Temp;
          my ($fh, $fn) = File::Temp::tempfile();
@@ -132,6 +130,7 @@ function POST() { adenosine POST "$@"; };
 function PUT() { adenosine PUT "$@"; };
 function DELETE() { adenosine DELETE "$@"; };
 function TRACE() { adenosine TRACE "$@"; };
+function PATCH() { adenosine TRACE "$@"; };
 SHELL
    } else {
       my $uri_base = $self->uri_base($action);
@@ -288,13 +287,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Adenosine - Handy CLI HTTP tool
 
 =head1 VERSION
 
-version 2.001006
+version 2.001007
 
 =head1 NOTE
 
@@ -381,7 +382,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
